Package: Rmmquant
Type: Package
Title: RNA-Seq multi-mapping Reads Quantification Tool
Version: 1.28.0
Date: 2023-04-05
Authors@R: person("Zytnicki", "Matthias", email = "matthias.zytnicki@inra.fr",
  role = c("aut", "cre"))
Description: RNA-Seq is currently used routinely, and it provides accurate
  information on gene transcription. However, the method cannot accurately
  estimate duplicated genes expression. Several strategies have been previously
  used, but all of them provide biased results.
  With Rmmquant, if a read maps at different positions, the tool detects that
  the corresponding genes are duplicated; it merges the genes and creates a
  merged gene. The counts of ambiguous reads is then based on the input genes
  and the merged genes.
  Rmmquant is a drop-in replacement of the widely used tools findOverlaps and
  featureCounts that handles multi-mapping reads in an unabiased way.
License: GPL-3
Encoding: UTF-8
SystemRequirements: C++11
Depends: R (>= 3.6)
Imports: Rcpp (>= 0.12.8), methods, S4Vectors, GenomicRanges,
        SummarizedExperiment, devtools, TBX20BamSubset,
        TxDb.Mmusculus.UCSC.mm9.knownGene, org.Mm.eg.db, DESeq2,
        apeglm, BiocStyle
LinkingTo: Rcpp
RoxygenNote: 7.0.2
biocViews: GeneExpression, Transcription
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/Rmmquant
git_branch: RELEASE_3_22
git_last_commit: 60d48d5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 06:06:52 UTC; biocbuild
Author: Zytnicki Matthias [aut, cre]
Maintainer: Zytnicki Matthias <matthias.zytnicki@inra.fr>

# Generated by roxygen2: do not edit by hand

export(RmmquantClassExample)
export(RmmquantExample)
export(RmmquantRun)
export(counts)
exportMethods(counts)
exportMethods(show)
import(BiocStyle)
import(GenomicRanges)
import(S4Vectors)
import(SummarizedExperiment)
import(TBX20BamSubset)
import(TxDb.Mmusculus.UCSC.mm9.knownGene)
import(devtools)
import(org.Mm.eg.db)
importFrom(DESeq2,DESeq)
importFrom(DESeq2,DESeqDataSetFromMatrix)
importFrom(DESeq2,lfcShrink)
importFrom(Rcpp,evalCpp)
importFrom(methods,is)
importFrom(methods,new)
useDynLib(Rmmquant)

## ----setup_knitr, include = FALSE, cache = FALSE------------------------------
library("Rmmquant")
library("BiocStyle")
library("S4Vectors")
library("SummarizedExperiment")
library("knitr")
library("rmarkdown")
library("TBX20BamSubset")
library("TxDb.Mmusculus.UCSC.mm9.knownGene")
library("org.Mm.eg.db")
library("DESeq2")
opts_chunk$set(message = FALSE, error = FALSE, warning = FALSE,
               cache = FALSE, fig.width = 5, fig.height = 5)

## ----first--------------------------------------------------------------------
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)
gtfFile <- file.path(dir, "test.gtf")
bamFile <- file.path(dir, "test.bam")
output <- RmmquantRun(gtfFile, bamFile)

## ----matrix-------------------------------------------------------------------
assays(output)$counts

## ----counts-------------------------------------------------------------------
assays(output)$counts

## ----stats--------------------------------------------------------------------
colData(output)

## ----bamfiles-----------------------------------------------------------------
bamFiles    <- getBamFileList()
sampleNames <- names(bamFiles)

## ----annotation---------------------------------------------------------------
gr <- genes(TxDb.Mmusculus.UCSC.mm9.knownGene, filter=list(tx_chrom="chr19"))

## ----ensembl------------------------------------------------------------------
ensemblIds <- sapply(as.list(org.Mm.egENSEMBL[mappedkeys(org.Mm.egENSEMBL)])
                     [mcols(gr)$gene_id], `[[`, 1)
gr         <- gr[! is.na(names(ensemblIds)), ]
names(gr)  <- unlist(ensemblIds)

## ----deseq2-------------------------------------------------------------------
output   <- RmmquantRun(genomicRanges=gr, readsFiles=bamFiles,
                        sampleNames=sampleNames, sorts=FALSE)
coldata <- data.frame(condition=factor(c(rep("control", 3), rep("KO", 3)),
                                       levels=c("control", "KO")),
                      row.names=sampleNames)
dds      <- DESeqDataSetFromMatrix(countData=assays(output)$counts,
                                   colData  =coldata,
                                   design   =~ condition)
dds      <- DESeq(dds)
res      <- lfcShrink(dds, coef=2)
res$padj <- ifelse(is.na(res$padj), 1, res$padj)
res[res$padj < 0.05, ]

## ----session_info-------------------------------------------------------------
devtools::session_info()

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

rcpp_parseGenomicRanges <- function(genomicRanges) {
    invisible(.Call('_Rmmquant_rcpp_parseGenomicRanges', PACKAGE = 'Rmmquant', genomicRanges))
}

rcpp_Rmmquant <- function(annotationFile, readsFiles, genomicRanges, genomicRangesList, sampleNames, overlap, strands, sorts, countThreshold, mergeThreshold, printGeneName, quiet, progress, nThreads, formats, nOverlapDiff, pcOverlapDiff) {
    .Call('_Rmmquant_rcpp_Rmmquant', PACKAGE = 'Rmmquant', annotationFile, readsFiles, genomicRanges, genomicRangesList, sampleNames, overlap, strands, sorts, countThreshold, mergeThreshold, printGeneName, quiet, progress, nThreads, formats, nOverlapDiff, pcOverlapDiff)
}

#' Rmmquant object validation function.
#'
#' @param object A \code{RmmquantClass} object.
#' @return       \code{TRUE}, if succeed, otherwise a \code{character}.
validateRmmquant <- function(object) {
    errors <- character()
    if ((! is.character(object@annotationFile)) |
        (! is.atomic(object@annotationFile))) {
        errors <- c(errors, "Annotation file should be one file name.")
    }
    if ((object@annotationFile == "") & (length(object@genomicRanges) == 0) &
        (length(object@genomicRangesList) == 0)) {
        errors <- c(errors, "Missing annotation.")
    }
    if (((object@annotationFile != "") &
         (length(object@genomicRanges) != 0)) |
        ((object@annotationFile != "") &
         (length(object@genomicRangesList) != 0)) |
        ((length(object@genomicRanges) != 0) &
         (length(object@genomicRangesList) != 0))) {
        errors <- c(errors, "At least two annotation inputs given.")
    }
    if ((object@annotationFile != "") & (! file.exists(object@annotationFile))){
        errors <- c(errors, paste0("Cannot open the annotation file '",
                                   object@annotationFile, "'."))
    }
    if (length(object@readsFiles) == 0) {
        errors <- c(errors, "At least one SAM/BAM file should be given.")
    }
    for (fileName in object@readsFiles) {
        if (! file.exists(fileName)) {
            errors <- c(errors, paste0("Cannot open the SAM/BAM file '",
                                       fileName, "'."))
        }
    }
    return(if (length(errors) == 0) TRUE else errors)
}

#' An S4 class for Rmmquant.
#'
#' @slot annotationFile    The annotation file
#' @slot readsFiles        The reads files
#' @slot genomicRanges     The annotation, in a
#'                              \code{GenomicRanges} format.
#' @slot genomicRangesList The annotation, in a
#'                              \code{GenomicRangesList} format.
#' @slot sampleNames       The name of the samples
#' @slot overlap           The minimum number of overlapping base pairs to
#'                              declare a match.
#' @slot strands           Whether annotation of the same strand should be
#'                              considered.
#' @slot sorts             Whether the files are sorted.
#' @slot countThreshold    The reads files
#' @slot mergeThreshold    The reads files
#' @slot printGeneName     Whether the (vernacular) gene name is reported.
#' @slot quiet             Shut Rmmquant up.
#' @slot progress          Print the progress of the tool.
#' @slot nThreads          The number of threads.
#' @slot formats           The format of the reads files (SAM or BAM).
#' @slot nOverlapDiff      Difference of overlap between a primary map and a
#'                             secondary map.
#' @slot pcOverlapDiff     Ratio of overlap between a primary map and a
#'                             secondary map.
#' @slot counts            A \code{SummarizedExperiment} storing the counts.
setClass("RmmquantClass",
         representation(
             annotationFile    ="character",
             readsFiles        ="character",
             genomicRanges     ="GRanges",
             genomicRangesList ="GRangesList",
             sampleNames       ="character",
             overlap           ="numeric",
             strands           ="character",
             sorts             ="logical",
             countThreshold    ="numeric",
             mergeThreshold    ="numeric",
             printGeneName     ="logical",
             quiet             ="logical",
             progress          ="logical",
             nThreads          ="numeric",
             formats           ="character",
             nOverlapDiff      ="numeric",
             pcOverlapDiff     ="numeric",
             counts            ="SummarizedExperiment"),
         prototype=list(
                        readsFiles        =character(0),
                        genomicRanges     =GRanges(),
                        genomicRangesList =GRangesList(),
                        sampleNames       =character(0),
                        overlap           =NA_integer_,
                        strands           =character(0),
                        sorts             =logical(0),
                        countThreshold    =NA_integer_,
                        mergeThreshold    =NA_real_,
                        printGeneName     =FALSE,
                        quiet             =TRUE,
                        progress          =FALSE,
                        nThreads          =1,
                        formats           =character(0),
                        nOverlapDiff      =NA_integer_,
                        pcOverlapDiff     =NA_real_),
         validity=validateRmmquant)

#' Main Rmmquant function.
#'
#' @param annotationFile    The annotation file
#' @param readsFiles        The reads files
#' @param genomicRanges     The annotation, in a
#'                              \code{GenomicRanges} format.
#' @param genomicRangesList The annotation, in a
#'                              \code{GenomicRangesList} format.
#' @param sampleNames       The name of the samples
#' @param overlap           The minimum number of overlapping base pairs to
#'                              declare a match.
#' @param strands           Whether annotation of the same strand should be
#'                              considered.
#' @param sorts             Whether the files are sorted.
#' @param countThreshold    The reads files
#' @param mergeThreshold    The reads files
#' @param printGeneName     Whether the (vernacular) gene name is reported.
#' @param quiet             Shut Rmmquant up.
#' @param progress          Print the progress of the tool.
#' @param nThreads          The number of threads.
#' @param formats           The format of the reads files (SAM or BAM).
#' @param nOverlapDiff      Difference of overlap between a primary map and a
#'                              secondary map.
#' @param pcOverlapDiff     Ratio of overlap between a primary map and a
#'                              secondary map.
#' @param lazyload          Usual for S4 functions.
#' @return                  A \code{SummerizedExperiment}.
#' @examples
#' dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)
#' gtfFile <- file.path(dir, "test.gtf")
#' samFile <- file.path(dir, "test.sam")
#' table <- RmmquantRun(gtfFile, samFile)
#'
#' @export
RmmquantRun <- function(annotationFile    ="",
                        readsFiles        =character(0),
                        genomicRanges     =GRanges(),
                        genomicRangesList =GRangesList(),
                        sampleNames       =character(0),
                        overlap           =NA_integer_,
                        strands           =character(0),
                        sorts             =logical(0),
                        countThreshold    =NA_integer_,
                        mergeThreshold    =NA_real_,
                        printGeneName     =FALSE,
                        quiet             =TRUE,
                        progress          =FALSE,
                        nThreads          =1,
                        formats           =character(0),
                        nOverlapDiff      =NA_integer_,
                        pcOverlapDiff     =NA_real_,
                        lazyload          =FALSE) {
    object <- new("RmmquantClass",
                  annotationFile   =annotationFile,
                  readsFiles       =readsFiles,
                  genomicRanges    =genomicRanges,
                  genomicRangesList=genomicRangesList,
                  sampleNames      =sampleNames,
                  overlap          =overlap,
                  strands          =strands,
                  sorts            =sorts,
                  countThreshold   =countThreshold,
                  mergeThreshold   =mergeThreshold,
                  printGeneName    =printGeneName,
                  quiet            =quiet,
                  progress         =progress,
                  nThreads         =nThreads,
                  nOverlapDiff     =nOverlapDiff,
                  pcOverlapDiff    =pcOverlapDiff)
    data <- rcpp_Rmmquant(annotationFile,
                          readsFiles,
                          genomicRanges,
                          genomicRangesList,
                          sampleNames,
                          overlap,
                          strands,
                          sorts,
                          countThreshold,
                          mergeThreshold,
                          printGeneName,
                          quiet,
                          progress,
                          nThreads,
                          formats,
                          nOverlapDiff,
                          pcOverlapDiff)
    counts           <- data$counts
    stats            <- DataFrame(data$stats,
                                  row.names=make.names(colnames(counts),
                                                       unique=TRUE))
    colnames(counts) <- rownames(stats)
    object@counts    <- SummarizedExperiment(assays=list(counts=counts),
                                             colData=stats)
    return(object@counts)
}

#' Example of Rmmquant use
#' @return An \code{SummarizedExperiement}.
#'
#' @examples
#' example <- RmmquantExample()
#'
#' @export
RmmquantExample <- function() {
    dir     <- system.file("extdata", package="Rmmquant", mustWork = TRUE)
    gtfFile <- file.path(dir, "test.gtf")
    samFile <- file.path(dir, "test.sam")
    return(RmmquantRun(gtfFile, samFile))
}


#' Example of Rmmquant constructor.
#' @return An \code{RmmquantClass}.
#'
#' @examples
#' example <- RmmquantExample()
#'
#' @export
RmmquantClassExample <- function() {
    dir     <- system.file("extdata", package="Rmmquant", mustWork = TRUE)
    gtfFile <- file.path(dir, "test.gtf")
    samFile <- file.path(dir, "test.sam")
    object  <- new("RmmquantClass", annotationFile=gtfFile, readsFiles=samFile)
    return(object)
}

#' Show the content of an \code{RmmquantClass} object.
#' @param object An \code{RmmquantClass} object.
#' @return       A description of the object.
#'
#' @examples
#' example <- RmmquantClassExample()
#' example
#'
#' @export
setMethod("show",
          signature(object="RmmquantClass"),
          function(object) {
                cat("Object of class Rmmquant.\n",
                    "Counts (length = ",
                    length(object@counts),
                    "):\n", sep="")
                show(object@counts)
            }
)

#' Get the counts table of an \code{RmmquantClass} object.
#' @rdname counts-method
#' @param  object  An \code{RmmquantClass} object.
#' @return         The count matrix, in a \code{SummarizedExperiment}
#'
#' @examples
#' example <- RmmquantClassExample()
#' counts(example)
#'
#' @export
setGeneric("counts", function(object) { standardGeneric("counts") } )

#' @rdname counts-method
#' @export
setMethod("counts",
          signature(object="RmmquantClass"),
          function(object) { object@counts })

suppressWarnings(suppressMessages(library(Rmmquant)))
suppressWarnings(suppressMessages(library(testthat)))
suppressWarnings(suppressMessages(library(GenomicRanges)))

context("Output tests")
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)

test_that("Running default test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(gtfFile, samFile)
    table       <- assays(se)[[1]]
    stats       <- colData(se)
    expect_is(se, "SummarizedExperiment")
    expect_is(table, "matrix")
    expect_is(stats, "DataFrame")
})

test_that("Running empty output", {
    gtfFile <- file.path(dir, "test.gtf")
    samFile <- file.path(dir, "test.sam")
    invisible(capture.output(se <- RmmquantRun(annotationFile=gtfFile,
                                               readsFiles    =samFile,
                                               overlap       =10000),
                             type="message"))
    table <- assays(se)$counts
    expect_is(table, "matrix")
    expect_equal(dim(table), c(0, 1))
})

suppressWarnings(suppressMessages(library(Rmmquant)))
suppressWarnings(suppressMessages(library(testthat)))
suppressWarnings(suppressMessages(library(GenomicRanges)))

context("Parameter tests")
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)

test_that("Running full parameter test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(annotationFile   =gtfFile,
                               genomicRanges    =GRanges(),
                               genomicRangesList=GRangesList(),
                               readsFiles       =c(samFile),
                               sampleNames      =c("test"),
                               overlap          =1,
                               strands          =c("U"),
                               sorts            =c(TRUE),
                               countThreshold   =1,
                               mergeThreshold   =0.0,
                               printGeneName    =FALSE,
                               quiet            =TRUE,
                               progress         =FALSE,
                               nThreads         =1,
                               formats          =c("SAM"),
                               nOverlapDiff     =30,
                               pcOverlapDiff    =0.5)
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
})

test_that("Running sample name test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(annotationFile   =gtfFile,
                               genomicRanges    =GRanges(),
                               genomicRangesList=GRangesList(),
                               readsFiles       =c(samFile),
                               sampleNames      ="name")
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("name"))
    expect_equal(table, m)
})

test_that("Running unsorted reads test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(annotationFile   =gtfFile,
                               genomicRanges    =GRanges(),
                               genomicRangesList=GRangesList(),
                               readsFiles       =c(samFile),
                               sorts            =c(FALSE))
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
})

test_that("Running two threads test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(annotationFile   =gtfFile,
                               genomicRanges    =GRanges(),
                               genomicRangesList=GRangesList(),
                               readsFiles       =c(samFile, samFile),
                               nThreads         =2)
    table       <- assays(se)$counts
    m           <- matrix(c(1, 1), 1, 2)
    dimnames(m) <- list(c("geneA"), c("test", "test.1"))
    expect_equal(table, m)
})

suppressWarnings(suppressMessages(library(Rmmquant)))
suppressWarnings(suppressMessages(library(testthat)))
suppressWarnings(suppressMessages(library(GenomicRanges)))

context("Case tests")
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)

test_that("Running two chromosomes test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="+")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="+")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test1.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile)
    table       <- assays(se)$counts
    m           <- matrix(c(1, 1), 2, 1)
    dimnames(m) <- list(c("geneA", "geneB"), c("test1"))
    expect_equal(table, m)
})

test_that("Running multi-mapped read test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="+")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="+")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test2.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile)
    table       <- assays(se)$counts
    m           <- matrix(c(1), 1, 1)
    dimnames(m) <- list(c("geneA--geneB"), c("test2"))
    expect_equal(table, m)
})

test_that("Running antisense unknown test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="+")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="-")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test1.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile)
    table       <- assays(se)$counts
    m           <- matrix(c(1, 1), 2, 1)
    dimnames(m) <- list(c("geneA", "geneB"), c("test1"))
    expect_equal(table, m)
})

test_that("Running antisense forward test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="+")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="-")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test1.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile, strands="F")
    table       <- assays(se)$counts
    m           <- matrix(c(1), 1, 1)
    dimnames(m) <- list(c("geneA"), c("test1"))
    expect_equal(table, m)
})

test_that("Running antisense reverse test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="+")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="-")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test1.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile, strands="R")
    table       <- assays(se)$counts
    m           <- matrix(c(1), 1, 1)
    dimnames(m) <- list(c("geneB"), c("test1"))
    expect_equal(table, m)
})

test_that("Running antisense both test", {
    gr1         <- GRanges(seqnames="chr1", ranges=IRanges(c(1000, 3000), width=1001, names="geneA"), strand="-")
    gr2         <- GRanges(seqnames="chr2", ranges=IRanges(c(5000, 8000), width=1001, names="geneB"), strand="*")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    samFile     <- file.path(dir, "test1.sam")
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=samFile, strands="F")
    table       <- assays(se)$counts
    m           <- matrix(c(1), 1, 1)
    dimnames(m) <- list(c("geneB"), c("test1"))
    expect_equal(table, m)
})

suppressWarnings(suppressMessages(library(Rmmquant)))
suppressWarnings(suppressMessages(library(testthat)))
suppressWarnings(suppressMessages(library(GenomicRanges)))

context("Input tests")
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)

test_that("Running SAM file test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(gtfFile, samFile)
    table       <- assays(se)$counts
    stats       <- colData(se)
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
    expect_equal(stats$n.hits,                     2)
    expect_equal(stats$n.uniquely.mapped.reads,    1)
    expect_equal(stats$n.ambiguously.mapped.hits,  0)
    expect_equal(stats$n.non.uniquely.mapped.hits, 0)
    expect_equal(stats$n.unassigned.hits,          1)
})
    
test_that("Running two SAM files test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.sam")
    se          <- RmmquantRun(gtfFile, c(samFile, samFile))
    table       <- assays(se)$counts
    m           <- matrix(c(1, 1), 1, 2)
    dimnames(m) <- list(c("geneA"), c("test", "test.1"))
    expect_equal(table, m)
})
    
test_that("Running BAM file test", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "test.bam")
    se          <- RmmquantRun(gtfFile, samFile)
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
})
    
test_that("Running genomic ranges test", {
    samFile     <- file.path(dir, "test.sam")
    gr          <- GRanges(seqnames="chr1",
                           ranges=IRanges(1000, width=3000, names="geneA"),
                           strand="+")
    se          <- RmmquantRun(genomicRanges=gr, readsFiles=c(samFile))
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
})

test_that("Running genomic ranges list test", {
    samFile     <- file.path(dir, "test.sam")
    gr1         <- GRanges(seqnames="chr1",
                           ranges=IRanges(c(1000, 3000),
                                          width=1001, names="geneA"),
                           strand="+")
    gr2         <- GRanges(seqnames="chr2",
                           ranges=IRanges(c(1000, 3000),
                                          width=1001, names="geneB"),
                           strand="+")
    grl         <- GRangesList("geneA"=gr1, "geneB"=gr2)
    se          <- RmmquantRun(genomicRangesList=grl, readsFiles=c(samFile))
    table       <- assays(se)$counts
    m           <- matrix(1, 1, 1)
    dimnames(m) <- list(c("geneA"), c("test"))
    expect_equal(table, m)
})

test_that("Running with several threads", {
    samFile     <- file.path(dir, "test.sam")
    gr          <- GRanges(seqnames="chr1",
                           ranges  =IRanges(1000, width=3000, names="geneA"),
                           strand  ="+")
    se          <- RmmquantRun(genomicRanges=gr,
                               readsFiles   =c(samFile, samFile),
                               sorts        =TRUE,
                               nThreads     =6)
    table       <- assays(se)$counts
    m           <- matrix(c(1, 1), 1, 2)
    dimnames(m) <- list(c("geneA"), c("test", "test.1"))
    expect_equal(table, m)
})


test_that("Running with no BAM/SAM file", {
    gtfFile <- file.path(dir, "test.gtf")
    expect_error(RmmquantRun(annotationFile=gtfFile))
})

test_that("Running with no GTF file", {
    samFile <- file.path(dir, "test.sam")
    expect_error(RmmquantRun(readsFiles=samFile))
})

test_that("Running with wrong SAM/BAM file name", {
    gtfFile     <- file.path(dir, "test.gtf")
    samFile     <- file.path(dir, "xxxx.sam")
    expect_error(RmmquantRun(annotationFile=gtfFile, readsFiles=samFile))
})

test_that("Running with wrong GTF file name", {
    gtfFile     <- file.path(dir, "xxxx.gtf")
    samFile     <- file.path(dir, "test.sam")
    expect_error(RmmquantRun(annotationFile=gtfFile, readsFiles=samFile))
})

#' Rmmquant: RNA-Seq multi-mapping Reads Quantification Tool
#'
#' Counts the number of reads per gene.
#'
#' @docType package
#' @name Rmmquant
#'
#' @author Matthias Zytnicki, \email{matthias.zytnicki@@inra.fr}
#'
#' @import S4Vectors
#' @import GenomicRanges
#' @import SummarizedExperiment
#' @import devtools
#' @import BiocStyle
#' @import TBX20BamSubset
#' @import TxDb.Mmusculus.UCSC.mm9.knownGene
#' @import org.Mm.eg.db
#' @importFrom DESeq2 DESeqDataSetFromMatrix
#' @importFrom DESeq2 DESeq
#' @importFrom DESeq2 lfcShrink
#' @importFrom methods is
#' @importFrom methods new
#' @importFrom Rcpp evalCpp
#' @useDynLib Rmmquant
NULL

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{RmmquantClassExample}
\alias{RmmquantClassExample}
\title{Example of Rmmquant constructor.}
\usage{
RmmquantClassExample()
}
\value{
An \code{RmmquantClass}.
}
\description{
Example of Rmmquant constructor.
}
\examples{
example <- RmmquantExample()

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\docType{class}
\name{RmmquantClass-class}
\alias{RmmquantClass-class}
\title{An S4 class for Rmmquant.}
\description{
An S4 class for Rmmquant.
}
\section{Slots}{

\describe{
\item{\code{annotationFile}}{The annotation file}

\item{\code{readsFiles}}{The reads files}

\item{\code{genomicRanges}}{The annotation, in a
\code{GenomicRanges} format.}

\item{\code{genomicRangesList}}{The annotation, in a
\code{GenomicRangesList} format.}

\item{\code{sampleNames}}{The name of the samples}

\item{\code{overlap}}{The minimum number of overlapping base pairs to
declare a match.}

\item{\code{strands}}{Whether annotation of the same strand should be
considered.}

\item{\code{sorts}}{Whether the files are sorted.}

\item{\code{countThreshold}}{The reads files}

\item{\code{mergeThreshold}}{The reads files}

\item{\code{printGeneName}}{Whether the (vernacular) gene name is reported.}

\item{\code{quiet}}{Shut Rmmquant up.}

\item{\code{progress}}{Print the progress of the tool.}

\item{\code{nThreads}}{The number of threads.}

\item{\code{formats}}{The format of the reads files (SAM or BAM).}

\item{\code{nOverlapDiff}}{Difference of overlap between a primary map and a
secondary map.}

\item{\code{pcOverlapDiff}}{Ratio of overlap between a primary map and a
secondary map.}

\item{\code{counts}}{A \code{SummarizedExperiment} storing the counts.}
}}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Rmmquant.R
\docType{package}
\name{Rmmquant}
\alias{Rmmquant}
\title{Rmmquant: RNA-Seq multi-mapping Reads Quantification Tool}
\description{
Counts the number of reads per gene.
}
\author{
Matthias Zytnicki, \email{matthias.zytnicki@inra.fr}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{RmmquantRun}
\alias{RmmquantRun}
\title{Main Rmmquant function.}
\usage{
RmmquantRun(
  annotationFile = "",
  readsFiles = character(0),
  genomicRanges = GRanges(),
  genomicRangesList = GRangesList(),
  sampleNames = character(0),
  overlap = NA_integer_,
  strands = character(0),
  sorts = logical(0),
  countThreshold = NA_integer_,
  mergeThreshold = NA_real_,
  printGeneName = FALSE,
  quiet = TRUE,
  progress = FALSE,
  nThreads = 1,
  formats = character(0),
  nOverlapDiff = NA_integer_,
  pcOverlapDiff = NA_real_,
  lazyload = FALSE
)
}
\arguments{
\item{annotationFile}{The annotation file}

\item{readsFiles}{The reads files}

\item{genomicRanges}{The annotation, in a
\code{GenomicRanges} format.}

\item{genomicRangesList}{The annotation, in a
\code{GenomicRangesList} format.}

\item{sampleNames}{The name of the samples}

\item{overlap}{The minimum number of overlapping base pairs to
declare a match.}

\item{strands}{Whether annotation of the same strand should be
considered.}

\item{sorts}{Whether the files are sorted.}

\item{countThreshold}{The reads files}

\item{mergeThreshold}{The reads files}

\item{printGeneName}{Whether the (vernacular) gene name is reported.}

\item{quiet}{Shut Rmmquant up.}

\item{progress}{Print the progress of the tool.}

\item{nThreads}{The number of threads.}

\item{formats}{The format of the reads files (SAM or BAM).}

\item{nOverlapDiff}{Difference of overlap between a primary map and a
secondary map.}

\item{pcOverlapDiff}{Ratio of overlap between a primary map and a
secondary map.}

\item{lazyload}{Usual for S4 functions.}
}
\value{
A \code{SummerizedExperiment}.
}
\description{
Main Rmmquant function.
}
\examples{
dir <- system.file("extdata", package="Rmmquant", mustWork = TRUE)
gtfFile <- file.path(dir, "test.gtf")
samFile <- file.path(dir, "test.sam")
table <- RmmquantRun(gtfFile, samFile)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{RmmquantExample}
\alias{RmmquantExample}
\title{Example of Rmmquant use}
\usage{
RmmquantExample()
}
\value{
An \code{SummarizedExperiement}.
}
\description{
Example of Rmmquant use
}
\examples{
example <- RmmquantExample()

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{validateRmmquant}
\alias{validateRmmquant}
\title{Rmmquant object validation function.}
\usage{
validateRmmquant(object)
}
\arguments{
\item{object}{A \code{RmmquantClass} object.}
}
\value{
\code{TRUE}, if succeed, otherwise a \code{character}.
}
\description{
Rmmquant object validation function.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{show,RmmquantClass-method}
\alias{show,RmmquantClass-method}
\title{Show the content of an \code{RmmquantClass} object.}
\usage{
\S4method{show}{RmmquantClass}(object)
}
\arguments{
\item{object}{An \code{RmmquantClass} object.}
}
\value{
A description of the object.
}
\description{
Show the content of an \code{RmmquantClass} object.
}
\examples{
example <- RmmquantClassExample()
example

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{counts}
\alias{counts}
\alias{counts,RmmquantClass-method}
\title{Get the counts table of an \code{RmmquantClass} object.}
\usage{
counts(object)

\S4method{counts}{RmmquantClass}(object)
}
\arguments{
\item{object}{An \code{RmmquantClass} object.}
}
\value{
The count matrix, in a \code{SummarizedExperiment}
}
\description{
Get the counts table of an \code{RmmquantClass} object.
}
\examples{
example <- RmmquantClassExample()
counts(example)

}
